#[non_exhaustive]pub enum AxoprojectError {
Show 17 variants
Axoasset(AxoassetError),
Axoprocess(AxoprocessError),
CargoMetadata(Error),
ParseChangelog(Error),
Generic(GenericManifestParseError),
FromUtf8(FromUtf8Error),
ParseCargoToml {
source: SourceFile,
span: Option<SourceSpan>,
details: TomlError,
},
NamelessNpmPackage {
manifest: Utf8PathBuf,
},
BuildInfoParse {
manifest_path: Utf8PathBuf,
details: Error,
},
InconsistentRepositoryKey {
file1: Utf8PathBuf,
url1: String,
file2: Utf8PathBuf,
url2: String,
},
AutoIncludeSearch {
dir: Utf8PathBuf,
details: Error,
},
UnknownRepoStyle {
url: String,
},
RepoParseError {
repo: String,
},
UrlParseError(ParseError),
NotGitHubError {
url: String,
},
ChangelogVersionNotFound {
path: Utf8PathBuf,
version: Version,
},
CargoMissing {},
}Expand description
An Error/Diagnostic returned by Axoproject
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Axoasset(AxoassetError)
Axoasset returned an error (I/O error)
Axoprocess(AxoprocessError)
Axoprocess returned an error (I/O error)
CargoMetadata(Error)
An error occurred in guppy/cargo-metadata when trying to find a cargo project
ParseChangelog(Error)
An error occurred in parse_changelog
Generic(GenericManifestParseError)
An error parsing a dist manifest
FromUtf8(FromUtf8Error)
An error producing a string
ParseCargoToml
An error parsing a Cargo.toml
NamelessNpmPackage
We found a package.json but it didn’t have “name” set
Fields
manifest: Utf8PathBufpath to the package.json
BuildInfoParse
We tried to get the bins from a package.json but something went wrong
InconsistentRepositoryKey
Your workspace gave several different values for “repository”
AutoIncludeSearch
An error that occurred while trying to find READMEs and whatnot in your project dir
UnknownRepoStyle
An error that occurred while trying to parse a repository string
RepoParseError
An error that occurred because a repository string could not be parsed for a specific reason
UrlParseError(ParseError)
An error that occurred when parsing a repository string
NotGitHubError
An error returned when a non-GitHub URL is parsed
ChangelogVersionNotFound
We searched a changelog file but found no result
CargoMissing
We couldn’t parse a workspace because there’s no Cargo